; Colors used for syntax-highlighting
(custom-set-faces
 '(vhdl-font-lock-attribute-face ((t (:bold t :foreground "cyan"))))
 '(font-lock-comment-face ((((class color) (background light)) (:foreground "darkgreen"))))
 '(font-lock-string-face ((((class color) (background light)) (:foreground "darkslategrey"))))
 '(font-lock-keyword-face ((((class color) (background light)) (:foreground "blue"))))
 '(font-lock-constant-face ((t (:bold t :foreground "DarkBlue"))))
 '(font-lock-type-face ((((class color) (background light)) (:italic t :foreground "Blue"))))
 '(font-lock-variable-name-face ((((class color) (background light)) (:italic t :foreground "red4"))))
 '(font-lock-function-name-face ((((class color) (background light)) (:bold t :foreground "red4"))))
 '(font-lock-builtin-face ((((class color) (background light)) (:foreground "firebrick")))))

; We want some stuff loaded by default
(require 'w3)

; Where to load GNUS etc from
  (setq load-path 
        (cons (expand-file-name "/usr/local/share/emacs/site-lisp/") load-path))
  (setq Info-default-directory-list 
        (cons "/usr/local/share/emacs/site-lisp/" Info-default-directory-list))

; Cool mailcrypting stuff
(load-library "mailcrypt")
(mc-setversion "gpg")
(autoload 'mc-install-write-mode "mailcrypt" nil t)
(autoload 'mc-install-read-mode "mailcrypt" nil t)
(add-hook 'gnus-summary-mode-hook 'mc-install-read-mode)
(add-hook 'message-mode-hook 'mc-install-write-mode)
(add-hook 'news-reply-mode-hook 'mc-install-write-mode)
;; If you have more than one key, specify the one to use
(setq mc-gpg-user-id "Remco Brink")
;; Always sign encrypted messages
(setq mc-pgp-always-sign t)
;; How long should mailcrypt remember your passphrase
(setq mc-passwd-timeout 600)
;; Automagically sign all messages
(add-hook 'message-send-hook 'will-you-sign)
(defun will-you-sign ()
        (load-library "mc-toplev")
        (interactive)
        (if (y-or-n-p "Do you want to sign this message? ")
                (mc-sign-message)))


;; Call fetchmail - I figured this out after the fortune hack above
(defun fetchmail ()
  (interactive)
  (shell-command-to-string "fetchmail"))

; replace-signature will replace the signature in an email
(defun replace-signature () (interactive)
  (let ((starthere (point)))
    (goto-char (point-min))
    (search-forward-regexp "^--text")
    (next-line 1)
    (search-forward-regexp "^--")
    (next-line 1)
    (beginning-of-line)
    (let ((beg (point)))
      (goto-char (point-max))
      (delete-region beg (point)))
    (shell-command-to-string "~/bin/signature.sh")
    (insert-file "~/.signature")
    (goto-char starthere)))

; Print the ASCII table
(defun ascii-table ()
  "Print the ascii table. Based on a defun by Alex Schroeder <asc@bsiag.com>"
  (interactive)
  (switch-to-buffer "*ASCII*")
  (erase-buffer)
  (insert (format "ASCII characters up to number %d.\n" 254))
  (let ((i 0))
    (while (< i 254)
      (setq i (+ i 1))
      (insert (format "%4d %c\n" i i))))
  (beginning-of-buffer))

; Select everything
(defun select-all ()
  (interactive)
  (set-mark (point-min))
  (goto-char (point-max)))

; Insert the date
(defun insert-date ()
  "Insert date at point."
  (interactive)
  (insert (format-time-string "%a %b %e, %Y %l:%M %p")))

; Convert from DOS > UNIX
(defun dos-unix ()
  (interactive)
    (goto-char (point-min))
      (while (search-forward "\r" nil t) (replace-match "")))

; Convert from UNIX > DOS
(defun unix-dos ()
  (interactive)
    (goto-char (point-min))
      (while (search-forward "\n" nil t) (replace-match "\r\n")))

;; replace y-e-s by y
(fset 'yes-or-no-p 'y-or-n-p)

; location of netscape, for browse-url:
(setq browse-url-netscape-program "/usr/bin/url_handler.sh")

;; Keys definitions
; Set proper delete key
(global-set-key [delete] `backward-delete-char)
; Select everything
(global-set-key "\C-a" 'select-all)
; hitting "PrtScrn" prints
(global-set-key [print] 'ps-print-buffer-with-faces)
; Ctrl-Tab switches buffers
(global-set-key [(ctrl tab)] 'bury-buffer)
; hitting "F8" browses the active URL
(global-set-key [f8] 'browse-url-at-point)
; hitting "F11" runs fetchmail
(global-set-key [f11] 'fetchmail) 
; hitting "F12" replaces the signature
(global-set-key [f12] 'replace-signature)


; Enable syntax highlighting
(toggle-global-lazy-font-lock-mode)

; Display full iso8859-1 character set
(set-input-mode t nil '8bit)
(standard-display-european 1)

; Custom filename extensions
(setq auto-mode-alist
      (append '(
                ("\\.ephtml$"   . perl-mode)
                ) auto-mode-alist))
(setq auto-mode-alist
      (append '(
                ("\\.dtxt$"   . perl-mode)
                ) auto-mode-alist))

; Use scp as ange-ftp program. Some .el-file seems to be required.
;(setq ange-ftp-gateway-program "ssh")
;(setq ange-ftp-ftp-program-name "scp")
;(setq ange-ftp-gateway-ftp-program-name "scp")
;(setq ange-ftp-ftp-program-args '("-i" "-n" "-g" "-v"))
; A list of arguments passed to the FTP program when started.


; Load the Java Developers Environment
;(setq load-path (nconc '("/home/eivind/.elisp/jde-2.1.5" ) load-path))
;(require 'jde)

; Key bindings
(global-set-key "\C-g" 'goto-line)

; This is default! How do you say Delete-key in lisp?
(global-set-key "\C-?" 'delete-backward-char)

(custom-set-variables
; '(ps-number-of-columns 2)
 '(ps-portrait-mode t)
 '(ps-paper-type (quote a4))
 '(ps-print-header nil))


(setq user-full-name "Remco B. Brink")
(setq user-mail-address "remco@solbors.no")
(setq mail-host-address "solbors.no")
